pub struct Connection { /* private fields */ }Expand description
Connection pool Minimal session will have at least 2 requests - login and query
Implementations
Sourceimpl Connection
impl Connection
pub fn new() -> Result<Self, ConnectionError>
Sourcepub fn new_with_middware(client: ClientWithMiddleware) -> Self
pub fn new_with_middware(client: ClientWithMiddleware) -> Self
Allow a user to provide their own middleware
Users can provide their own middleware to the connection like this:
use snowflake_api::connection::Connection;
let mut client = Connection::default_client_builder();
// modify the client builder here
let connection = Connection::new_with_middware(client.unwrap().build());This is not intended to be called directly, but is used by SnowflakeApiBuilder::with_client
pub fn default_client_builder() -> Result<ClientBuilder, ConnectionError>
Sourcepub async fn request<R: DeserializeOwned>(
&self,
query_type: QueryType,
account_identifier: &str,
extra_get_params: &[(&str, &str)],
auth: Option<&str>,
body: impl Serialize,
) -> Result<R, ConnectionError>
pub async fn request<R: DeserializeOwned>( &self, query_type: QueryType, account_identifier: &str, extra_get_params: &[(&str, &str)], auth: Option<&str>, body: impl Serialize, ) -> Result<R, ConnectionError>
Perform request of given query type with extra body or parameters
pub async fn get_chunk( &self, url: &str, headers: &HashMap<String, String>, ) -> Result<Bytes, ConnectionError>